==> linuxconf-1.21.src.tar.gz: linuxconf-1.21/userconf/internal.h <==
#pragma interface
#ifndef INTERNAL_H
#define INTERNAL_H

#ifndef MISC_H
	#include <misc.h>
#endif

class USERCONF_HELP_FILE: public HELP_FILE{
	/*~PROTOBEG~ USERCONF_HELP_FILE */
public:
	USERCONF_HELP_FILE (const char *fname);
	/*~PROTOEND~ USERCONF_HELP_FILE */
};

class PASSWD_VALID{
public:
	char privgroup;		// Allocate one group per user
	int minlen;
	int minnonalpha;
	int createperm;
	SSTRING defhome;
	SSTRING createcmd;
	SSTRING deletecmd;
	SSTRING archivecmd;
	SSTRING postdeletecmd;
	char showshadow;
	char showexpire;
	char mayedithome;
	char mayeditshell;
	char mayeditquota;
	char mayedittasks;
	/*~PROTOBEG~ PASSWD_VALID */
public:
	PASSWD_VALID (void);
	void edit (void);
	void write (void);
	/*~PROTOEND~ PASSWD_VALID */
};

class SHADOW: public ARRAY_OBJ{
	friend class SHADOWS;
	friend class USER;
	friend class USERS;
	SSTRING name;
	SSTRING passwd;
	int last;
	int may;
	int must;
	int warn;
	int expire;
	int disable;
	SSTRING reserved;
	/*~PROTOBEG~ SHADOW */
public:
	SHADOW (const char *line);
	SHADOW (void);
	int getdisable (void)const;
	int getexpire (void)const;
	int getmaychange (void)const;
	int getmustchange (void)const;
	const char *getpwd (void)const;
	int getwarn (void)const;
private:
	void initdef (void);
public:
	void setdialog (DIALOG&dia);
	void write (FILE_CFG *fout);
	int writedef (void);
	/*~PROTOEND~ SHADOW */
};

class SHADOWS: public ARRAY{
	CONFIG_FILE *configf;
	/*~PROTOBEG~ SHADOWS */
public:
	SHADOWS (CONFIG_FILE&_configf);
	SHADOWS (void);
	SHADOW *getitem (const char *name);
	SHADOW *getitem (int no);
private:
	void readusers (void);
public:
	void reload (void);
	int write (PRIVILEGE *priv);
	/*~PROTOEND~ SHADOWS */
};

extern const char subsys_useraccounts[];
extern const char subsys_policies[];
extern int (*perm_fct_change) (const char *user, bool pre_authenticated);


#endif

==> linuxconf-1.34r3.src.tar.gz: linuxconf-1.34r3/userconf/internal.h <==
#pragma interface
#ifndef INTERNAL_H
#define INTERNAL_H

#ifndef MISC_H
	#include <misc.h>
#endif

class USERCONF_HELP_FILE: public HELP_FILE{
	/*~PROTOBEG~ USERCONF_HELP_FILE */
public:
	USERCONF_HELP_FILE (const char *fname);
	/*~PROTOEND~ USERCONF_HELP_FILE */
};

class PASSWD_VALID{
public:
	char privgroup;		// Allocate one group per user
	int minlen;
	int minnonalpha;
	int createperm;
	SSTRING defhome;
	SSTRING createcmd;
	SSTRING deletecmd;
	SSTRING archivecmd;
	SSTRING postdeletecmd;
	char showshadow;
	char showexpire;
	char mayedithome;
	char mayeditshell;
	char mayeditquota;
	char mayedittasks;
	char createhome;
	SSTRING autopasswd;
	SSTRING autoupasswd;
	bool forceupasswd;
	/*~PROTOBEG~ PASSWD_VALID */
public:
	PASSWD_VALID (void);
	void edit (void);
	void write (void);
	/*~PROTOEND~ PASSWD_VALID */
};

class SHADOW;

class SHADOWS: private ARRAY{
	class SHADOWS_private *priv;
	CONFIG_FILE *configf;
	/*~PROTOBEG~ SHADOWS */
public:
	SHADOWS (CONFIG_FILE&_configf);
	SHADOWS (void);
	void add (SHADOW *s);
	SHADOW *getitem (const char *name);
	SHADOW *getitem (int no);
private:
	void readusers (void);
public:
	void reload (void);
	void remove_del (SHADOW *s);
	int write (PRIVILEGE *priv);
	~SHADOWS (void);
	/*~PROTOEND~ SHADOWS */
};

class M_DIALOG;

extern const char subsys_useraccounts[];
extern const char subsys_policies[];
extern int (*perm_fct_change) (
		const char *user,
		bool pre_authenticated,
		const char *suggested,
		void (*fct_html) (M_DIALOG &dia, bool intro));


#endif
